@@ -45,7 +45,7 @@
 //! [`assert_markdown_deps_updated`]: macro.assert_markdown_deps_updated.html
 //! [`assert_html_root_url_updated`]: macro.assert_html_root_url_updated.html
 
-#![doc(html_root_url = "https://docs.rs/version-sync/0.2.0")]
+#![doc(html_root_url = "https://docs.rs/version-sync/0.3.0")]
 
 extern crate pulldown_cmark;
 extern crate semver_parser;
@@ -179,8 +179,15 @@ fn extract_version_request(pkg_name: &str, block: &str) -> Result<VersionReq> {
 fn is_toml_block(lang: &str) -> bool {
     // Split the language line as LangString::parse from rustdoc:
     // https://github.com/rust-lang/rust/blob/1.20.0/src/librustdoc/html/markdown.rs#L922
-    lang.split(|c: char| !(c == '_' || c == '-' || c.is_alphanumeric()))
-        .any(|token| token.trim() == "toml")
+    let mut has_toml = false;
+    for token in lang.split(|c: char| !(c == '_' || c == '-' || c.is_alphanumeric())) {
+        match token.trim() {
+            "no_sync" => return false,
+            "toml" => has_toml = true,
+            _ => {}
+        }
+    }
+    has_toml
 }
 
 /// Find all TOML code blocks in a Markdown text.
@@ -216,7 +223,30 @@ fn find_toml_blocks(text: &str) -> Vec<CodeBlock> {
 /// dependencies on `pkg_name` in those blocks. A code block fails the
 /// check if it has a dependency on `pkg_name` that doesn't match
 /// `pkg_version`, or if it has no dependency on `pkg_name` at all.
-/// Code blocks also fails the check if they cannot be parsed as TOML.
+///
+/// # Examples
+///
+/// Consider a package named `foo` with version 1.2.3. The following
+/// TOML block will pass the test:
+///
+/// ~~~markdown
+/// ```toml
+/// [dependencies]
+/// foo = "1.2.3"
+/// ```
+/// ~~~
+///
+/// Both `dependencies` and `dev-dependencies` are examined. If you
+/// want to skip a block, add `no_sync` to the language line:
+///
+/// ~~~markdown
+/// ```toml,no_sync
+/// [dependencies]
+/// foo = "1.2.3"
+/// ```
+/// ~~~
+///
+/// Code blocks also fail the check if they cannot be parsed as TOML.
 ///
 /// # Errors
 ///
@@ -485,12 +515,18 @@ mod tests {
 
     #[test]
     fn is_toml_block_simple() {
-        assert!(!is_toml_block("rust"))
+        assert!(!is_toml_block("rust"));
     }
 
     #[test]
     fn is_toml_block_comma() {
-        assert!(is_toml_block("foo,toml"))
+        assert!(is_toml_block("foo,toml"));
+    }
+
+    #[test]
+    fn is_toml_block_no_sync() {
+        assert!(!is_toml_block("toml,no_sync"));
+        assert!(!is_toml_block("toml, no_sync"));
     }
 
     mod test_version_matches_request {
